@@ -16,7 +16,9 @@
  ***************************************************************************/
 
 #include "barcodedialogs.h"
-#include "mybarcode.h"
+#include "barkode.h"
+#include "purepostscript.h"
+#include "tbarcode2.h"
 
 // Qt includes
 #include <qbuttongroup.h>
@@ -34,6 +36,7 @@
 #include <kcombobox.h>
 #include <knuminput.h>
 #include <klocale.h>
+#include <kcolorbutton.h>
 
 
 AdvancedBarcodeDialog::AdvancedBarcodeDialog( QString type, QWidget* parent, const char* name )
@@ -42,24 +45,36 @@ AdvancedBarcodeDialog::AdvancedBarcodeDialog( QString type, QWidget* parent, con
 {
     list.setAutoDelete( false );
     
-    if( BarCode::hasFeature( type, PDF417BARCODE ) ) {
+    if( Barkode::hasFeature( type, PDF417BARCODE ) ) {
         QVBox* box = addVBoxPage( i18n("PDF417") );
         PDF417BarcodeDlg* dlg = new PDF417BarcodeDlg( box );
         list.append( (BarcodeDlgBase*)dlg );
     }
 
-    if( BarCode::hasFeature( type, DATAMATRIX ) ) {
+    if( Barkode::hasFeature( type, DATAMATRIX ) ) {
         QVBox* box = addVBoxPage( i18n("DataMatrix") );
         DataMatrixDlg* dlg = new DataMatrixDlg( box );
         list.append( (BarcodeDlgBase*)dlg );        
     }
 
-    if( BarCode::hasFeature( type, TBARCODEADV ) ) {
+    if( Barkode::hasFeature( type, TBARCODEADV ) ) {
         QVBox* box = addVBoxPage( i18n("TBarcode") );
         TBarcodeDlg* dlg = new TBarcodeDlg( box );
         list.append( (BarcodeDlgBase*)dlg );        
     }
 
+    if( Barkode::hasFeature( type, PUREADV ) ) {
+        QVBox* box = addVBoxPage( i18n("Barcode Writer in Pure Postscript") );
+        PurePostscriptDlg* dlg = new PurePostscriptDlg( box );
+        list.append( (BarcodeDlgBase*)dlg );        
+    }
+
+    if( Barkode::hasFeature( type, COLORED ) ) {
+        QVBox* box = addVBoxPage( i18n("Colors") );
+        ColorDlg* dlg = new ColorDlg( box );
+        list.append( (BarcodeDlgBase*)dlg );        
+    }
+
     QVBox* box = addVBoxPage( i18n("Sequence") );
     SequenceDlg* dlg = new SequenceDlg( box );
     list.append( (BarcodeDlgBase*)dlg );
@@ -69,7 +84,7 @@ AdvancedBarcodeDialog::~AdvancedBarcodeDialog()
 {
 }
 
-void AdvancedBarcodeDialog::setData( const barcodeData* b )
+void AdvancedBarcodeDialog::setData( Barkode* b )
 {
     for( unsigned int i = 0; i < list.count(); i++ ) {
         BarcodeDlgBase* bdb = list.at( i );
@@ -77,7 +92,7 @@ void AdvancedBarcodeDialog::setData( const barcodeData* b )
     }
 }
 
-void AdvancedBarcodeDialog::getData( barcodeData* b ) 
+void AdvancedBarcodeDialog::getData( Barkode* b ) 
 {
     for( unsigned int i = 0; i < list.count(); i++ ) {
         BarcodeDlgBase* bdb = list.at( i );
@@ -94,13 +109,17 @@ TBarcodeDlg::TBarcodeDlg(QWidget *parent, const char *name )
     gb->setColumnLayout(0, Qt::Vertical );
     gb->layout()->setSpacing( 6 );
     gb->layout()->setMargin( 11 );
-    gb->setEnabled( BarCode::haveTBarcode() );
+    gb->setEnabled( Barkode::haveTBarcode() || Barkode::haveTBarcode2() );
     QVBoxLayout* gbLayout = new QVBoxLayout( gb->layout() );
 
     spinModule = new KDoubleNumInput( gb );
     spinModule->setLabel( i18n("Module width (mm):"), AlignLeft | AlignVCenter );
     spinModule->setRange( 0.190, 1.500, 0.001, true );
 
+    spinHeight = new KIntNumInput( gb );
+    spinHeight->setLabel( i18n("Barcode Height (mm):"), AlignLeft | AlignVCenter );
+    spinHeight->setRange( 1, 1000, 10, false );
+
     checkEscape = new QCheckBox( i18n("&Translate escape sequences"), gb );
     checkAbove = new QCheckBox( i18n("&Text above barcode"), gb );
     checkAutoCorrect = new QCheckBox( i18n("&Auto correction"), gb );
@@ -115,6 +134,7 @@ TBarcodeDlg::TBarcodeDlg(QWidget *parent, const char *name )
     hbox->addWidget( comboCheckSum );
             
     gbLayout->addWidget( spinModule );
+    gbLayout->addWidget( spinHeight );
     gbLayout->addWidget( checkEscape );
     gbLayout->addWidget( checkAbove );
     gbLayout->addWidget( checkAutoCorrect );
@@ -127,95 +147,107 @@ TBarcodeDlg::TBarcodeDlg(QWidget *parent, const char *name )
     layout->addWidget( gb );
 }
 
-void TBarcodeDlg::setData( const barcodeData* b )
+void TBarcodeDlg::setData( Barkode* b )
 {
-    spinModule->setValue( b->tbarcode.modulewidth );
-    checkEscape->setChecked( b->tbarcode.escape );
-    checkAbove->setChecked( b->tbarcode.above );
-    checkAutoCorrect->setChecked( b->tbarcode.autocorrect );
+    TBarcodeOptions* options = dynamic_cast<TBarcodeOptions*>( b->engine()->options() );
 
-    map.insert( i18n("No Checksum"), 0 );
-    map.insert( i18n("Default Checksum Method"), 1 );
-
-    if( BarCode::hasFeature( b->type, MODULOALLCHECK ) ||
-        BarCode::hasFeature( b->type, MODULO10CHECK ) )
-        map.insert( i18n("Modulo 10 Checksum"), 2 );
+    if( options ) 
+    {
+        spinModule->setValue( options->moduleWidth() );
+        spinHeight->setValue( options->height() );
+        checkEscape->setChecked( options->escape() );
+        checkAbove->setChecked( options->above() );
+        checkAutoCorrect->setChecked( options->autocorrect() );
     
-    if( BarCode::hasFeature( b->type, MODULOALLCHECK ) ||
-        b->type == "b13" || // EAN 13
-        b->type == "b14" || // EAN 13
-        b->type == "b15" || // EAN 13
-        b->type == "b18" ) // CodaBar (2 width)
-        map.insert( i18n("Module 43 (suggested for Code39 and Logmars, 1 digit)"), 3 );
+        map.insert( i18n("No Checksum"), 0 );
+        map.insert( i18n("Default Checksum Method"), 1 );
 
-    if( BarCode::hasFeature( b->type, MODULOALLCHECK ) )
-        map.insert( i18n("Modula 47 (2 digits)"), 4 );
+        if( Barkode::hasFeature( b->type(), MODULOALLCHECK ) ||
+            Barkode::hasFeature( b->type(), MODULO10CHECK ) )
+            map.insert( i18n("Modulo 10 Checksum"), 2 );
+    
+        if( Barkode::hasFeature( b->type(), MODULOALLCHECK ) ||
+            b->type() == "b13" || // EAN 13
+            b->type() == "b14" || // EAN 13
+            b->type() == "b15" || // EAN 13
+            b->type() == "b18" ) // CodaBar (2 width)
+            map.insert( i18n("Module 43 (suggested for Code39 and Logmars, 1 digit)"), 3 );
+        
+        if( Barkode::hasFeature( b->type(), MODULOALLCHECK ) )
+            map.insert( i18n("Modula 47 (2 digits)"), 4 );
+        
+        if( b->type() == "b21" ) // Deutsche Post Leitcode
+            map.insert( i18n("Deutsche Post Leitcode"), 5 );
+        
+        if( b->type() == "b22") // Deutsche Post Identcode
+            map.insert( i18n("Deutsche Post Identcode"), 6 );
 
-    if( b->type == "b21" ) // Deutsche Post Leitcode
-        map.insert( i18n("Deutsche Post Leitcode"), 5 );
-
-    if( b->type == "b22") // Deutsche Post Identcode
-        map.insert( i18n("Deutsche Post Identcode"), 6 );
-
-    if( b->type == "b1" ) { // Code11
+        if( b->type() == "b1" ) { // Code11
         map.insert( i18n("Code 11 (1 digit)"), 7 );
         map.insert( i18n("Code 11 (2 digits)"), 8 );
-    }
+        }
 
-    if( BarCode::hasFeature( b->type, POSTNETCHECK ) )
-        map.insert( i18n("USPS Postnet"), 9 );
+        if( Barkode::hasFeature( b->type(), POSTNETCHECK ) )
+            map.insert( i18n("USPS Postnet"), 9 );
 
-    if( b->type == "b47" ) { // MSI
-        map.insert( i18n("MSI (1 digit)"), 10 );
-        map.insert( i18n("MSI (2 digits)"), 11 );
-    }
+        if( b->type() == "b47" ) { // MSI
+            map.insert( i18n("MSI (1 digit)"), 10 );
+            map.insert( i18n("MSI (2 digits)"), 11 );
+        }
 
-    if( b->type == "b46" ) // Plessey
-        map.insert( i18n("Plessey"), 12 );
+        if( b->type() == "b46" ) // Plessey
+            map.insert( i18n("Plessey"), 12 );
 
-    if( BarCode::hasFeature( b->type, EAN8CHECK ) )
-        map.insert( i18n("EAN 8"), 13 );
+        if( Barkode::hasFeature( b->type(), EAN8CHECK ) )
+            map.insert( i18n("EAN 8"), 13 );
 
-    if( BarCode::hasFeature( b->type, EAN13CHECK ) )    
-        map.insert( i18n("EAN 13"), 14 );
+        if( Barkode::hasFeature( b->type(), EAN13CHECK ) )    
+            map.insert( i18n("EAN 13"), 14 );
 
-    if( BarCode::hasFeature( b->type, UPCACHECK ) )
-        map.insert( i18n("UPC A"), 15 );
+        if( Barkode::hasFeature( b->type(), UPCACHECK ) )
+            map.insert( i18n("UPC A"), 15 );
+        
+        if( Barkode::hasFeature( b->type(), UPCECHECK ) )
+            map.insert( i18n("UPC E"), 16 );
 
-    if( BarCode::hasFeature( b->type, UPCECHECK ) )
-        map.insert( i18n("UPC E"), 16 );
+        if( b->type() == "b16" )  // EAN 128
+            map.insert( i18n("EAN 128"), 17 );
 
-    if( b->type == "b16" )  // EAN 128
-        map.insert( i18n("EAN 128"), 17 );
+        if( Barkode::hasFeature( b->type(),  CODE128CHECK ) )
+            map.insert( i18n("Code 128"), 18 );
+        
+        if( b->type() == "b70" ) // Royal Mail 4 State
+            map.insert( i18n("Royal Mail 4 State"), 19 );
 
-    if( BarCode::hasFeature( b->type,  CODE128CHECK ) )
-        map.insert( i18n("Code 128"), 18 );
-
-    if( b->type == "b70" ) // Royal Mail 4 State
-        map.insert( i18n("Royal Mail 4 State"), 19 );
-
-    comboCheckSum->insertStringList( map.keys() );
-       
-    QMap<QString,int>::Iterator it;
-    for ( it = map.begin(); it != map.end(); ++it ) {
-        if( it.data() == b->tbarcode.checksum ) {
-            for( int i = 0; i < comboCheckSum->count(); i++ )
-                if( comboCheckSum->text( i ) == it.key() ) {
-                    comboCheckSum->setCurrentItem( i );
-                    break;
-                }
-            break;
+        comboCheckSum->insertStringList( map.keys() );
+        
+        QMap<QString,int>::Iterator it;
+        for ( it = map.begin(); it != map.end(); ++it ) {
+            if( it.data() == options->checksum() ) {
+                for( int i = 0; i < comboCheckSum->count(); i++ )
+                    if( comboCheckSum->text( i ) == it.key() ) {
+                        comboCheckSum->setCurrentItem( i );
+                        break;
+                    }
+                break;
+            }
         }
     }
 }
 
-void TBarcodeDlg::getData( barcodeData* b ) const
+void TBarcodeDlg::getData( Barkode* b ) const
 {
-    b->tbarcode.modulewidth = spinModule->value();
-    b->tbarcode.escape = checkEscape->isChecked();
-    b->tbarcode.above = checkAbove->isChecked();
-    b->tbarcode.autocorrect = checkAutoCorrect->isChecked();
-    b->tbarcode.checksum = map[comboCheckSum->currentText()];
+    TBarcodeOptions* options = dynamic_cast<TBarcodeOptions*>( b->engine()->options() );
+
+    if( options ) 
+    {
+        options->setModuleWidth( spinModule->value() );
+        options->setEscape( checkEscape->isChecked() );
+        options->setAbove( checkAbove->isChecked() );
+        options->setAutocorrect( checkAutoCorrect->isChecked() );
+        options->setCheckSum( map[comboCheckSum->currentText()] );
+        options->setHeight( spinHeight->value() );
+    }
 }
 
 PDF417BarcodeDlg::PDF417BarcodeDlg(QWidget *parent, const char *name )
@@ -227,7 +259,7 @@ PDF417BarcodeDlg::PDF417BarcodeDlg(QWidget *parent, const char *name )
     gpdf->setColumnLayout(0, Qt::Vertical );
     gpdf->layout()->setSpacing( 6 );
     gpdf->layout()->setMargin( 11 );
-    gpdf->setEnabled( BarCode::haveTBarcode() || BarCode::havePDFBarcode() );
+    gpdf->setEnabled( Barkode::haveTBarcode() || Barkode::havePDFBarcode() );
     QVBoxLayout* gpdfLayout = new QVBoxLayout( gpdf->layout() );
 
     spinRow = new KIntNumInput( gpdf );
@@ -248,18 +280,28 @@ PDF417BarcodeDlg::PDF417BarcodeDlg(QWidget *parent, const char *name )
     layout->addWidget( gpdf );
 }
 
-void PDF417BarcodeDlg::setData( const barcodeData* b )
+void PDF417BarcodeDlg::setData( Barkode* b )
 {
-    spinRow->setValue( b->pdf417.row );
-    spinCol->setValue( b->pdf417.col );
-    spinErr->setValue( b->pdf417.err );
+    PDF417Options* options = dynamic_cast<PDF417Options*>( b->engine()->options() );
+
+    if( options ) 
+    {
+        spinRow->setValue( options->row() );
+        spinCol->setValue( options->col() );
+        spinErr->setValue( options->err() );
+    }
 }
 
-void PDF417BarcodeDlg::getData( barcodeData* b ) const
+void PDF417BarcodeDlg::getData( Barkode* b ) const
 {
-    b->pdf417.row = spinRow->value();
-    b->pdf417.col = spinCol->value();
-    b->pdf417.err = spinErr->value();
+    PDF417Options* options = dynamic_cast<PDF417Options*>( b->engine()->options() );
+
+    if( options ) 
+    {
+        options->setRow( spinRow->value() );
+        options->setCol( spinCol->value() );
+        options->setErr( spinErr->value() );
+    }
 }
 
 DataMatrixDlg::DataMatrixDlg(QWidget *parent, const char *name )
@@ -306,14 +348,14 @@ DataMatrixDlg::DataMatrixDlg(QWidget *parent, const char *name )
     comboDataMatrix->insertItem( "16 x 48" );
 }
 
-void DataMatrixDlg::setData( const barcodeData* b )
+void DataMatrixDlg::setData( Barkode* b )
 {
-    comboDataMatrix->setCurrentItem( b->datamatrix.size );
+    comboDataMatrix->setCurrentItem( b->datamatrixSize());
 }
 
-void DataMatrixDlg::getData( barcodeData* b ) const
+void DataMatrixDlg::getData( Barkode* b ) const
 {
-    b->datamatrix.size = comboDataMatrix->currentItem();
+    b->setDatamatrixSize( comboDataMatrix->currentItem() );
 }
 
 SequenceDlg::SequenceDlg( QWidget *parent, const char *name )
@@ -356,41 +398,109 @@ SequenceDlg::SequenceDlg( QWidget *parent, const char *name )
     connect( radioAlphaNum, SIGNAL( clicked() ), this, SLOT( enableControls() ) );
 }
 
-void SequenceDlg::setData( const barcodeData* b )
+void SequenceDlg::setData( Barkode* b )
 {
-    checkSequence->setChecked( b->sequence.enabled );
-    spinStep->setValue( b->sequence.step );
-    spinStart->setValue( b->sequence.start );
+    checkSequence->setChecked( b->sequenceEnabled() );
+    spinStep->setValue( b->sequenceStep() );
+    spinStart->setValue( b->sequenceStart() );
     
-    if( b->sequence.mode == NUM )
+    if( b->sequenceMode() == NUM )
         radioNumbers->setChecked( true );
-    else if( b->sequence.mode == ALPHA )
+    else if( b->sequenceMode() == ALPHA )
         radioAlpha->setChecked( true );
-    else if( b->sequence.mode == ALPHANUM )
+    else if( b->sequenceMode() == ALPHANUM )
         radioAlphaNum->setChecked( true );
         
     enableControls();
 }
 
-void SequenceDlg::getData( barcodeData* b ) const
+void SequenceDlg::getData( Barkode* b ) const
 {
-    b->sequence.enabled = checkSequence->isChecked();
-    b->sequence.step = spinStep->value();
-    b->sequence.start = spinStart->value();
+    b->setSequenceEnabled( checkSequence->isChecked() );
+    
+    b->setSequenceStep( spinStep->value() );
+    b->setSequenceStart( spinStart->value() );
     
     if( radioNumbers->isChecked() )
-        b->sequence.mode = NUM;
+        b->setSequenceMode( NUM );
     else if( radioAlpha->isChecked() )
-        b->sequence.mode = ALPHA;
+        b->setSequenceMode( ALPHA );
     else if( radioAlphaNum->isChecked() )
-        b->sequence.mode = ALPHANUM;
+        b->setSequenceMode( ALPHANUM );
 }
 
 void SequenceDlg::enableControls()
 {
     radioNumbers->setEnabled( checkSequence->isChecked() );
     radioAlpha->setEnabled( checkSequence->isChecked() );
-    radioAlphaNum->setEnabled(false);// checkSequence->isChecked() );
+    radioAlphaNum->setEnabled( false ); //checkSequence->isChecked() );
     spinStep->setEnabled( checkSequence->isChecked() );
     spinStart->setEnabled( checkSequence->isChecked() && radioNumbers->isChecked() );
 }
+
+ColorDlg::ColorDlg(QWidget *parent, const char *name)
+    : QVBox( parent, name )
+{
+    QGroupBox* gb  = new QGroupBox( i18n("Colors"), this );
+    gb->setColumnLayout(0, Qt::Vertical );
+    gb->layout()->setSpacing( 6 );
+    gb->layout()->setMargin( 11 );
+    gb->setEnabled( Barkode::havePurePostscriptBarcode() );
+    QGridLayout* gbLayout = new QGridLayout( gb->layout() );
+
+    buttonBarColor = new KColorButton( gb );
+    buttonBackColor = new KColorButton( gb );
+    buttonTextColor = new KColorButton( gb );
+
+    gbLayout->addWidget( new QLabel( i18n("Bar Color:"), gb ), 0, 0 );
+    gbLayout->addWidget( new QLabel( i18n("Background Color:"), gb ), 1, 0 );
+    gbLayout->addWidget( new QLabel( i18n("Text Color:"), gb ), 2, 0 );
+    gbLayout->addWidget( buttonBarColor, 0, 1 );
+    gbLayout->addWidget( buttonBackColor, 1, 1 );
+    gbLayout->addWidget( buttonTextColor, 2, 1 );
+}
+
+void ColorDlg::setData( Barkode* b )
+{
+    buttonBarColor->setColor( b->foreground() );
+    buttonBackColor->setColor( b->background() );
+    buttonTextColor->setColor( b->textColor() );
+}
+
+void ColorDlg::getData( Barkode* b ) const
+{
+    b->setForeground( buttonBarColor->color() );
+    b->setBackground( buttonBackColor->color() );
+    b->setTextColor( buttonTextColor->color() );
+}
+
+PurePostscriptDlg::PurePostscriptDlg(QWidget *parent, const char *name)
+    : QVBox( parent, name )
+{
+    QVGroupBox* gb  = new QVGroupBox( i18n("Barcode Writer in Pure Postscript"), this );
+    gb->setEnabled( Barkode::havePurePostscriptBarcode() );
+    
+    checkChecksum = new QCheckBox( i18n("Enable &Checksum"), gb );
+}
+
+void PurePostscriptDlg::setData( Barkode* b )
+{
+    PurePostscriptOptions* options = dynamic_cast<PurePostscriptOptions*>( b->engine()->options() );
+
+    if( options ) 
+    {
+        checkChecksum->setChecked( options->checksum() );
+        checkChecksum->setEnabled( Barkode::hasFeature( b->type(), MODULOALLCHECK ) );
+    }
+}
+
+void PurePostscriptDlg::getData( Barkode* b ) const
+{
+    PurePostscriptOptions* options = dynamic_cast<PurePostscriptOptions*>( b->engine()->options() );
+    
+    if( options ) 
+        options->setChecksum( checkChecksum->isChecked() );
+}
+
+
+#include "barcodedialogs.moc"
