@@ -719,6 +719,9 @@ void Barkode::initInfo()
     if( s_havePurePostscript ) 
     {
         // add a leading "ps_" so that they do not conflict with GNU Barcode types
+        PurePostscriptBarcode::initInfo( &s_info );
+
+        /*
         s_info.append( createInfo( "ps_auspost", i18n("Australian Post"), PURE_POSTSCRIPT, PUREADV | COLORED | NOCUT ) );
         s_info.append( createInfo( "ps_code11", i18n("Code 11"), PURE_POSTSCRIPT, PUREADV | COLORED ) );
         s_info.append( createInfo( "ps_code128", i18n("Code 128"), PURE_POSTSCRIPT, PUREADV | COLORED ) );
@@ -740,6 +743,7 @@ void Barkode::initInfo()
         s_info.append( createInfo( "ps_symbol", i18n("Symbol"), PURE_POSTSCRIPT, PUREADV | COLORED ) );
         s_info.append( createInfo( "ps_upca", i18n("UPCA"), PURE_POSTSCRIPT, PUREADV | COLORED ) );
         s_info.append( createInfo( "ps_upce", i18n("UPCE"), PURE_POSTSCRIPT, PUREADV | COLORED ) );
+        */
     }
 
     if( s_haveTBarcode ) 
