@@ -555,6 +555,13 @@ void BatchWizard::printNow( const QString & printer, bool bUserInteraction )
     KPrinter* prn = NULL;
     int batchType = 0;
 
+    // let's check if the label file does even exist!
+    if( !QFile::exists( m_url->url() ) ) 
+    {
+        KMessageBox::error( this, QString( i18n("The label file %1 was not found") ).arg( m_url->url()) );
+        return;
+    }
+
     if( radioPrinter->isChecked() )
     {
 	int move = 0;
@@ -1070,6 +1077,7 @@ bool BatchWizard::fillVarTable()
 	QStringList data;
 	int i = 0;
 
+        file.setCSVFile(true);
 	if( !file.isValid() )
 	{
 	    KMessageBox::error( this, QString( i18n("Can't open file: %1") ).arg( importCsvFile->url() ) );
@@ -1088,15 +1096,21 @@ bool BatchWizard::fillVarTable()
 		if( m_varTable->numRows() <= i )
 		    m_varTable->setNumRows( i + 100 );	      
 
-		    
+                printf("datacount=%i\n", data.count() );
 		for( unsigned int z = 0; z < data.count(); z++ )
 		{
-		    for( int x = 0; x < m_varTable->numRows(); x++ )
+                    printf("numRows=%i\n", m_varTable->numCols() );
+		    for( int x = 0; x < m_varTable->numCols(); x++ )
+                    {
+                        printf("horizontal header=%s\n", m_varTable->horizontalHeader()->label( x ).lower().latin1() );
+                        printf("heading=%s\n", heading[z].lower().latin1() );
 			if( m_varTable->horizontalHeader()->label( x ).lower() == heading[z].lower() )
 			{
+                            printf("Reading: (%s)\n", data[z].latin1());
 			    m_varTable->setText( i, x, data[z] );
 			    break;
 			}
+                    }
 		}
 
 		if( data.count() )
