@@ -25,7 +25,7 @@
 CSVFile::CSVFile( const QString & filename )
 {
     m_eof = false;
-    m_csv = false;
+    m_csv = true;
 
     m_quote = PrinterSettings::getInstance()->getData()->quote;
     m_separator = PrinterSettings::getInstance()->getData()->separator;
@@ -41,7 +41,7 @@ CSVFile::CSVFile( const QString & filename )
 CSVFile::CSVFile( QBuffer & buf )
 {
     m_eof = false;
-    m_csv = false;
+    m_csv = true;
 
     m_quote = PrinterSettings::getInstance()->getData()->quote;
     m_separator = PrinterSettings::getInstance()->getData()->separator;
