@@ -17,7 +17,6 @@
 
 #include "definition.h"
 #include "sqltables.h"
-#include "measurements.h"
 
 // Qt includes
 #include <qtextstream.h>
@@ -30,6 +29,7 @@
 #include <klocale.h>
 #include <kmessagebox.h>
 #include <kstandarddirs.h>
+#include <qprogressdialog.h>
 
 // a simple helper function
 // that copies a file
@@ -63,19 +63,19 @@ class PrivateParser {
         PrivateParser( QString line, bool all = true );
         ~PrivateParser();
 
-        QString getId() const { return label_def_id; }
-        QString getProducer() const { return producer; }
-        QString getType() const { return type; }
-        Measurements* getMeasurements() const { return m; };
+        const QString & getId() const { return m_label_def_id; }
+        const QString & getProducer() const { return m_producer; }
+        const QString & getType() const { return m_type; }
+        const Measurements & getMeasurements() const { return m_measure; };
 
     private:
         QString removeQuote( const QString & q );
 
-        QString label_def_id;
-        QString producer;
-        QString type;
+        QString m_label_def_id;
+        QString m_producer;
+        QString m_type;
 
-        Measurements* m;
+        Measurements m_measure;
 };
 
 PrivateParser::PrivateParser( QString line, bool all )
@@ -84,28 +84,27 @@ PrivateParser::PrivateParser( QString line, bool all )
     int pos = line.find("(");
     line = line.mid( pos + 1, line.length() - pos - 1 );
 
-    m = new Measurements();
+    m_label_def_id = line.section( ",", 0, 0 ).stripWhiteSpace();
+    m_producer     = removeQuote( line.section( ",", 1, 1 ) );
+    m_type         = removeQuote( line.section( ",", 2, 2 ) );
 
-    label_def_id = line.section( ",", 0, 0 ).stripWhiteSpace();
-    producer = removeQuote( line.section( ",", 1, 1 ) );
-    type = removeQuote( line.section( ",", 2, 2 ) );
     if( all ) {
-        m->setGapTopMM( line.section( ",", 4, 4 ).toDouble() );
-        m->setGapLeftMM( line.section( ",", 5, 5 ).toDouble() );
-        m->setHeightMM( line.section( ",", 6, 6 ).toDouble() );
-        m->setWidthMM( line.section( ",", 7, 7 ).toDouble() );
-        m->setGapVMM( line.section( ",", 8, 8 ).toDouble() );
-        m->setGapHMM( line.section( ",", 9, 9 ).toDouble() );
-        m->setNumH( line.section( ",", 10, 10 ).toInt() );
-        m->setNumV( line.section( ",", 11, 11 ).toInt() );
+        m_measure.setGapTopMM( line.section( ",", 4, 4 ).toDouble() );
+        m_measure.setGapLeftMM( line.section( ",", 5, 5 ).toDouble() );
+        m_measure.setHeightMM( line.section( ",", 6, 6 ).toDouble() );
+        m_measure.setWidthMM( line.section( ",", 7, 7 ).toDouble() );
+        m_measure.setGapVMM( line.section( ",", 8, 8 ).toDouble() );
+        m_measure.setGapHMM( line.section( ",", 9, 9 ).toDouble() );
+        m_measure.setNumH( line.section( ",", 10, 10 ).toInt() );
+        m_measure.setNumV( line.section( ",", 11, 11 ).toInt() );
 
         // fix broken label definitions
         // with numh and numv = 0
-        if( !m->numH() )
-            m->setNumH( 1 );
+        if( !m_measure.numH() )
+            m_measure.setNumH( 1 );
 
-        if( !m->numV() )
-            m->setNumV( 1 );
+        if( !m_measure.numV() )
+            m_measure.setNumV( 1 );
     }
 }
 
@@ -128,28 +127,27 @@ QString PrivateParser::removeQuote( const QString & q )
 
 /***************************************************************************/
 
-Definition::Definition()
+Definition::Definition( QWidget* parent )
+    : m_parent( parent )
 {
     id = -1;
-    m = new Measurements();
 }
 
-Definition::Definition( int label_def_id )
+Definition::Definition( int label_def_id, QWidget* parent )
+    : m_parent( parent )
 {
-    m = new Measurements();
     init( QString("%1").arg( label_def_id ) );
 }
 
-Definition::Definition( const QString & label_def_id )
+Definition::Definition( const QString & label_def_id, QWidget* parent )
+    : m_parent( parent )
 {
-    m = new Measurements();
     init( label_def_id );
 }
 
-Definition::Definition( const QString & producer, const QString & type )
+Definition::Definition( const QString & producer, const QString & type, QWidget* parent )
+    : m_parent( parent )
 {
-    m = new Measurements();
-
     if( SqlTables::isConnected() ) {
         QSqlQuery query(
             "select label_no from " TABLE_LABEL_DEF " WHERE manufacture='" + producer + "' AND type='" + type + "'");
@@ -159,30 +157,65 @@ Definition::Definition( const QString & producer, const QString & type )
         if(!openFile())
             return;
 
+	initProgress();
+
         QString s;
         while( file->readLine( s, 1000 ) != -1 ) {
             if( s.isEmpty() || s.left( 1 ) == "#" )
                 continue;
 
+	    increaseProgress();
+
             PrivateParser p( s );
             if( p.getProducer() ==producer && p.getType() == type ) {
                 init( p.getId() );
                 break;
             }
         }
+
+	destroyProgress();
     }
 
 }
 
 Definition::~Definition()
 {
-    delete m;
 }
 
 QFile* Definition::file = 0;
 QByteArray* Definition::array = 0;
 QStringList* Definition::listProducers = 0;
 QMap<QString,QStringList> Definition::mapTypes;
+QProgressDialog* Definition::m_progress = 0;
+
+void Definition::initProgress()
+{
+/*
+    if(!m_progress)
+	m_progress = new QProgressDialog( i18n("Loading Label Definitions..."), QString::null, 0, NULL, "m_progress", true );
+
+    m_progress->setTotalSteps( 1000 );
+    m_progress->show();
+*/
+//    m_progress->reparent( m_parent, m_progress->pos(), true );
+}
+
+void Definition::increaseProgress()
+{
+/*
+    if( m_progress )
+	m_progress->setProgress( m_progress->progress() + 1 );
+*/
+}
+
+void Definition::destroyProgress()
+{
+/*
+    if( m_progress )
+	delete m_progress;
+    m_progress = NULL;
+*/
+}
 
 void Definition::setId( const QString & label_def_id )
 {
@@ -202,14 +235,14 @@ void Definition::init( const QString & label_def_id )
             " WHERE label_no = " + label_def_id );
 
         while( query->next() ) {
-            m->setNumH( query->value( 0 ).toInt() );
-            m->setNumV( query->value( 1 ).toInt() );
-            m->setGapLeftMM( query->value( 2 ).toDouble() );
-            m->setGapTopMM( query->value( 3 ).toDouble() );
-            m->setGapVMM( query->value( 4 ).toDouble() );
-            m->setGapHMM( query->value( 5 ).toDouble() );
-            m->setWidthMM( query->value( 6 ).toDouble() );
-            m->setHeightMM( query->value( 7 ).toDouble() );
+            m_measure.setNumH( query->value( 0 ).toInt() );
+            m_measure.setNumV( query->value( 1 ).toInt() );
+            m_measure.setGapLeftMM( query->value( 2 ).toDouble() );
+            m_measure.setGapTopMM( query->value( 3 ).toDouble() );
+            m_measure.setGapVMM( query->value( 4 ).toDouble() );
+            m_measure.setGapHMM( query->value( 5 ).toDouble() );
+            m_measure.setWidthMM( query->value( 6 ).toDouble() );
+            m_measure.setHeightMM( query->value( 7 ).toDouble() );
             producer = query->value( 8 ).toString();
             type = query->value( 9 ).toString();
         }
@@ -221,33 +254,39 @@ void Definition::init( const QString & label_def_id )
 
 }
 
-Measurements* Definition::getMeasurements() const
+const Measurements & Definition::getMeasurements() const
 {
-    return m;
+    return m_measure;
 }
 
 void Definition::getFileMeasurements( const QString & label_def_id )
 {
     if(!openFile()) {
-        m = new Measurements();
+        m_measure = Measurements();
         return;
     }
 
+    initProgress();
+
     QTextStream stream(*array, IO_ReadOnly );
     while( !stream.atEnd() ) {
         QString s = stream.readLine();
         if( s.isEmpty() || s.startsWith( "#" ) )
             continue;
 
+	increaseProgress();
+
         PrivateParser p( s );
         if( p.getId() != label_def_id )
             continue;
 
-        producer = p.getProducer();
-        type = p.getType();
-        m = p.getMeasurements();
+        producer  = p.getProducer();
+        type      = p.getType();
+        m_measure = p.getMeasurements();
         break;
     }
+
+    destroyProgress();
 }
 
 bool Definition::openFile()
@@ -303,16 +342,22 @@ const QStringList Definition::getProducers()
         if(!openFile() )
             return *listProducers;
 
+	initProgress();
+
         QTextStream stream(*array, IO_ReadOnly );
         while( !stream.atEnd() ) {
             QString s = stream.readLine();
             if( s.isEmpty() || s.startsWith( "#" ) )
                 continue;
 
+	    increaseProgress();
+
             PrivateParser p( s, false );
             if( !listProducers->contains( p.getProducer() ) )
                 listProducers->append( p.getProducer() );
         }
+
+	destroyProgress();
     }
 
     return *listProducers;
@@ -335,17 +380,23 @@ const QStringList Definition::getTypes( QString producer )
         if(!openFile())
             return list;
 
+	initProgress();
+
         QTextStream stream(*array, IO_ReadOnly );
         while( !stream.atEnd() ) {
             QString s = stream.readLine();
             if( s.isEmpty() || s.startsWith( "#" ) )
                 continue;
 
+	    increaseProgress();
+
             PrivateParser p( s, false );
             if( p.getProducer() == producer )
                 if( !list.contains( p.getType() ) )
                     list.append( p.getType() );
         }
+
+	destroyProgress();
     }
 
     mapTypes.insert( producer, list );
@@ -375,7 +426,7 @@ void Definition::updateProducer()
     }
 }
 
-int Definition::write( Measurements* c, QString type, QString producer )
+int Definition::write( const Measurements & c, QString type, QString producer )
 {
     int r = -1;
     if( SqlTables::isConnected() )
@@ -387,20 +438,20 @@ int Definition::write( Measurements* c, QString type, QString producer )
     return r;
 }
 
-int Definition::writeFile( Measurements* c, QString type, QString producer )
+int Definition::writeFile( const Measurements & c, QString type, QString producer )
 {
     if( !openFile() )
         return -1;
-
+        
     QStringList data;
     bool datawritten = false;
     int index = 0;
     QString entry = ", '" +
-                  producer + "', '" + type + "', 'C',"+ I2S(c->gapTopMM()) +
-                  ", " + I2S(c->gapLeftMM()) + ", " +
-                  I2S(c->heightMM()) + ", " + I2S(c->widthMM()) + ", " +
-                  I2S(c->gapVMM()) + ", " + I2S(c->gapHMM()) + ", " +
-                  I2S(c->numH()) + ", " + I2S(c->numV()) + ", NULL, NULL )";
+                  producer + "', '" + type + "', 'C',"+ I2S(c.gapTopMM()) +
+                  ", " + I2S(c.gapLeftMM()) + ", " +
+                  I2S(c.heightMM()) + ", " + I2S(c.widthMM()) + ", " +
+                  I2S(c.gapVMM()) + ", " + I2S(c.gapHMM()) + ", " +
+                  I2S(c.numH()) + ", " + I2S(c.numV()) + ", NULL, NULL )";
         
     QString s;
     while( file->readLine( s, 1000 ) != -1 ) {
@@ -444,7 +495,7 @@ int Definition::writeFile( Measurements* c, QString type, QString producer )
     return index + 1;
 }
 
-int Definition::writeSQL( Measurements* c, QString type, QString producer )
+int Definition::writeSQL( const Measurements & c, QString type, QString producer )
 {
     bool newitem = true;
     QSqlQuery q( "SELECT manufacture, type FROM " TABLE_LABEL_DEF );
@@ -458,26 +509,26 @@ int Definition::writeSQL( Measurements* c, QString type, QString producer )
         QSqlQuery query(
               "INSERT INTO " TABLE_LABEL_DEF " (manufacture, type, gap_top, gap_left, "
               "width, height, gap_v, gap_h, number_h, number_v) VALUES ('" +
-              producer + "', '" + type + "', '"+ I2S( c->gapTopMM() ) +
-              "', '" + I2S( c->gapLeftMM() ) + "', '" +
-              I2S( c->widthMM() ) + "', '" + I2S( c->heightMM() ) + "', '" +
-              I2S( c->gapVMM() ) + "', '" + I2S( c->gapHMM() ) + "', '" +
-              I2S( c->numH() ) + "', '" + I2S( c->numV() ) + "')"
+              producer + "', '" + type + "', '"+ I2S( c.gapTopMM() ) +
+              "', '" + I2S( c.gapLeftMM() ) + "', '" +
+              I2S( c.widthMM() ) + "', '" + I2S( c.heightMM() ) + "', '" +
+              I2S( c.gapVMM() ) + "', '" + I2S( c.gapHMM() ) + "', '" +
+              I2S( c.numH() ) + "', '" + I2S( c.numV() ) + "')"
               );
 
         if(!query.isValid())
             qDebug("Query to insert values not valid!");
     } else {
         QSqlQuery query( "UPDATE " TABLE_LABEL_DEF " SET "
-            "gap_top = " + I2S( c->gapTopMM() ) + " ,gap_left = " + I2S( c->gapLeftMM() ) +
-            " ,width = " + I2S( c->widthMM() ) + " ,height = " + I2S( c->heightMM() ) +
-            " ,gap_v = " + I2S( c->gapVMM() ) + " ,gap_h = " + I2S( c->gapHMM() ) +
-            " ,number_h = " + I2S( c->numH() ) + " ,number_v = " + I2S( c->numV() ) +
+            "gap_top = " + I2S( c.gapTopMM() ) + " ,gap_left = " + I2S( c.gapLeftMM() ) +
+            " ,width = " + I2S( c.widthMM() ) + " ,height = " + I2S( c.heightMM() ) +
+            " ,gap_v = " + I2S( c.gapVMM() ) + " ,gap_h = " + I2S( c.gapHMM() ) +
+            " ,number_h = " + I2S( c.numH() ) + " ,number_v = " + I2S( c.numV() ) +
             " WHERE manufacture = '" + producer + "' AND"
             " type = '" + type + "'" );
 
         if(!query.isValid())
-            qDebug("Query to update values not valid!\n" + query.lastQuery() );
+            qDebug("Query to update values not valid!\n%s\n", query.lastQuery().latin1() );
     }
 
     QSqlQuery qi("SELECT label_no FROM " TABLE_LABEL_DEF " WHERE manufacture='" + producer + "' AND type='" + type + "'" );
