@@ -16,9 +16,10 @@
  ***************************************************************************/
 
 #include "kbarcode.h"
+#include "barkode.h"
 #include "barcodedialog.h"
+#include "batchwizard.h"
 #include "labeleditor.h"
-#include "labelprinter.h"
 #include "databasebrowser.h"
 #include "csvimportdlg.h"
 #include "sqltables.h"
@@ -30,11 +31,13 @@
 
 // KDE includes
 #include <kaction.h>
+#include <kapplication.h>
 #include <kcmdlineargs.h>
 #include <kiconloader.h>
 #include <klocale.h>
 #include <kpopupmenu.h>
 #include <kpushbutton.h>
+#include <kmessagebox.h>
 
 KBarcode::KBarcode( QWidget *parent, const char *name, WFlags f)
     : DCOPObject("KBarcode"),
@@ -46,7 +49,7 @@ KBarcode::KBarcode( QWidget *parent, const char *name, WFlags f)
     setCentralWidget( w );
 
     buttonSingle = new KPushButton( i18n("Barcode &Generator..."), w );
-    buttonSingle->setEnabled( BarCode::haveBarcode() );
+    buttonSingle->setEnabled( Barkode::haveBarcode() );
     buttonEditor = new KPushButton( i18n("&Label Editor..."), w );
     buttonBatch = new KPushButton( i18n("&Batch Printing..."), w );
     buttonData = new KPushButton( i18n("Edit SQL &Tables..."), w );
@@ -94,7 +97,6 @@ KBarcode::KBarcode( QWidget *parent, const char *name, WFlags f)
     importCSVAct->plug( data );
 
     enableData();
-    parseCmdLine();
 }
 
 KBarcode::~KBarcode()
@@ -114,33 +116,33 @@ void KBarcode::startBarcode()
 
 void KBarcode::startLabelEditor()
 {
-    new LabelEditor( 0, QString::null, "LabelEditorWindow" );
+    LabelEditor* ed = new LabelEditor( NULL, QString::null, "LabelEditorWindow" );
+    ed->startupDlg( LabelEditor::eCreateNewLabel, QString::null );
 }
 
 void KBarcode::startBatchPrint()
 {
-    new LabelPrinter( QString::null, 0, "BatchPrintingWindow" );
+    new BatchWizard( this );
 }
 
-
 void KBarcode::editArticles()
 {
-    new DatabaseBrowser( TABLE_BASIC, 0, "basicbrowser" );
+    new DatabaseBrowser( TABLE_BASIC, NULL, "basicbrowser" );
 }
 
 void KBarcode::editCustomers()
 {
-    new DatabaseBrowser( TABLE_CUSTOMER, 0, "customerbrowser" );
+    new DatabaseBrowser( TABLE_CUSTOMER, NULL, "customerbrowser" );
 }
 
 void KBarcode::editCustomerText()
 {
-    new DatabaseBrowser( TABLE_CUSTOMER_TEXT, 0, "customertextbrowser" );
+    new DatabaseBrowser( TABLE_CUSTOMER_TEXT, NULL, "customertextbrowser" );
 }
 
 void KBarcode::editLabelDef()
 {
-    new DatabaseBrowser( TABLE_LABEL_DEF, 0, "defbrowser" );
+    new DatabaseBrowser( TABLE_LABEL_DEF, NULL, "defbrowser" );
 }
 
 void KBarcode::enableData()
@@ -148,38 +150,117 @@ void KBarcode::enableData()
     buttonData->setEnabled( SqlTables::getInstance()->isConnected() );
 }
 
-void KBarcode::parseCmdLine()
+bool KBarcode::parseCmdLine()
 {
+    enum { BARCODE, LABEL, BATCH, NONE } mode = NONE;
+
     KCmdLineArgs* args = KCmdLineArgs::parsedArgs();
-    bool print = args->isSet( "print" );
-    QString printer = args->getOption("d");
-    
-    for( int i = 0; i < args->count(); i++) {
-        LabelEditor* e = new LabelEditor( 0, args->url( i ).path() );
-        if( print ) {
-            e->print();
-        }
+
+    BatchPrinter::EOutputFormat eFormat = BatchPrinter::POSTSCRIPT;
+    LabelEditor* pEdit = NULL;
+    QString serial;
+    QString sqlquery   = QString::null;
+    QString csvfile    = QString::null;
+    QString printer    = QString::null;
+
+    bool bPrintNow     = args->isSet("print");
+    int serialinc      = 0;
+    int numlabels      = -1;
+
+    QString format = args->getOption("output");
+    if( format.upper() == "BARCODE" )
+	eFormat = BatchPrinter::BCP;
+    else if( format.upper() == "IMAGE" )
+	eFormat = BatchPrinter::IMAGE;
+    else if( format.upper() == "POSTSCRIPT" )
+	eFormat = BatchPrinter::POSTSCRIPT;
+    else
+    {
+	KMessageBox::error( this, i18n("%1 is no valid output format for --output. Valid values are POSTSCRIPT, IMAGE and BARCODE.").arg( format ) );
     }
 
-    if( args->isSet("single" ) )
-        startBarcode();
+    if( args->isSet("barcode") )
+    {
+	mode = BARCODE;
+	startBarcode();
+    }
 
     if( args->isSet("batch") )
-        startBatchPrint();
+	mode = BATCH;
+    
+    if( args->isSet("label") )
+	mode = LABEL;
 
-    if( args->isSet( "label" ) )
-        startLabelEditor();
-        
-    QCStringList optlist = args->getOptionList ( "b" );
-    for (QCStringList::ConstIterator it=optlist.begin(); it!=optlist.end(); ++it) {
-        LabelPrinter pr( *it );
-        pr.setCustomerId( args->getOption( "c" ) );
-        pr.setLabelURL( args->getOption( "l" ) );
-        if( print )
-            pr.print( true, printer );
+    if( args->isSet("serialnumber") )
+    {
+	serial = args->getOption("serialnumber");
+	if( args->isSet("serialinc") )
+	    serialinc = args->getOption("serialinc").toInt();
     }
 
-    args->clear();      // Free some memory
+    if( args->isSet("numlabels") )
+	numlabels = args->getOption("numlabels").toInt();
+
+    if( args->isSet("importsql") )
+	sqlquery = args->getOption("importsql");
+
+    if( args->isSet("importcsv") ) 
+	csvfile = args->getOption("importcsv");
+
+    if( args->isSet("printer") )
+	printer = args->getOption("printer");
+
+    for( int i = 0; i < args->count(); i++) 
+	if( mode == BATCH )
+	{
+	    BatchWizard* b = new BatchWizard();
+	    b->setFilename( args->url( i ).path() );
+	    b->setOutputFormat( eFormat );
+	    b->setSerialNumber( serial, serialinc );
+	    if( !sqlquery.isEmpty() )
+		b->setImportSqlQuery( sqlquery );
+
+	    if( !csvfile.isEmpty() )
+		b->setImportCsvFile( csvfile );
+
+	    if( numlabels != -1 )
+		b->setNumLabels( numlabels );
+
+	    if( bPrintNow )
+            {
+		b->printNow( printer, false );
+                delete b;
+            }
+	}
+	else
+        {
+	    pEdit = new LabelEditor( 0, args->url( i ).path() );
+            if( bPrintNow )
+                // TODO: use the printer set by the printer commandline option
+                pEdit->print(); 
+        }
+
+    if( !args->count() && mode == LABEL )
+    {
+        pEdit = new LabelEditor();
+        if( bPrintNow )
+            // TODO: use the printer set by the printer commandline option
+            pEdit->print(); 
+
+    }
+
+    int argc = args->count();
+    args->clear();  // Free some memory
+
+    // close after printing
+    if( bPrintNow && argc )
+    {
+        // TODO: really close the whole application
+        this->close();
+        return true;
+    }
+    else
+        return false;    
 }
 
 void KBarcode::importCSV()
@@ -207,3 +288,5 @@ void KBarcode::showConfigure()
     KBarcodeSettings::getInstance()->configure();
 }
 
+
+#include "kbarcode.moc"
