@@ -48,6 +48,12 @@ class KBarcode: public DSMainWindow, public KBarcodeIface {
         KBarcode( QWidget *parent=0, const char *name="kbarcode", WFlags f = WType_TopLevel | WDestructiveClose );
         ~KBarcode();
 
+        /** Parse all commandline options and start batchprinting
+         *  if necessary. 
+         *  \returns true if the application should exit after this function
+         */          
+        bool parseCmdLine();
+
     private slots:
         void startBarcode();
         void startLabelEditor();
@@ -64,7 +70,6 @@ class KBarcode: public DSMainWindow, public KBarcodeIface {
 
     private:
         void setupActions();
-        void parseCmdLine();
 
         /** allow the DCOP interface
           * to check for an SQL connection.
