@@ -260,11 +260,7 @@ void LabelEditor::clearLabel()
     for (; it != list.end(); ++it)
     {
 	citem = static_cast<TCanvasItem*>(*it);
-	if( !citem->remRef() )
-	{
-	    qDebug("Deleting Item because of Refcount=0");
-	    delete citem;
-	}
+	citem->remRef();
     }
 
     updateInfo();
