@@ -52,7 +52,7 @@ class LabelUtils {
         static QPixmap* drawString( const QString & t ) {
             return LabelUtils::drawString( t, 0, 0, 0 );
         }
-        static void renderString( QPainter* painter, const QString & t, int w, int h, double scalex, double scaley );
+        static void renderString( QPainter* painter, const QString & t, const QRect & r, double scalex, double scaley );
 
         const QString getTypeFromCaption( const QString & cap );
         const QString getModeFromCaption( const QString & cap );
