@@ -16,7 +16,7 @@
  ***************************************************************************/
 
 #include "multilineeditdlg.h"
-#include "textfields.h"
+#include "tokendialog.h"
 
 // KDE includes
 #include <kaction.h>
@@ -25,11 +25,7 @@
 #include <kfiledialog.h>
 #include <klocale.h>
 #include <kspell.h>
-#if QT_VERSION >= 0x030100
-    #include <ktextedit.h>
-#else
-    #include <qtextedit.h>
-#endif
+#include <dstextedit.h>
 #include <ktoolbar.h>
 #include <kcombobox.h>
 
@@ -37,25 +33,19 @@
 #include <qdockarea.h>
 #include <qregexp.h>
 
-MultiLineEditDlg::MultiLineEditDlg( QString text, QWidget *parent, const char *name )
-    : KDialogBase( KDialogBase::Plain, "Text",
-      KDialogBase::Ok | KDialogBase::Cancel, KDialogBase::Ok, parent,name)
-
+MultiLineEditor::MultiLineEditor( TokenProvider* token, QWidget *parent, const char *name )
+    : QWidget( parent, name ), m_token( token )
 {
-    QVBoxLayout* layout = new QVBoxLayout( plainPage(), 6, 6 );
+    QVBoxLayout* layout = new QVBoxLayout( this, 6, 6 );
 
 //    ksc = new KSpellConfig( this );
 
-#if QT_VERSION >= 0x030100
-    editor = new KTextEdit( plainPage() );
-#else
-    editor = new QTextEdit( plainPage() );
-#endif        
+    editor = new DSTextEdit( this );
     editor->setTextFormat( Qt::RichText );
-    editor->setText( text, "" );
+    //editor->setText( text, "" );
     editor->setFocus();
 
-    QDockArea* area = new QDockArea( Qt::Horizontal, QDockArea::Normal, plainPage() );
+    QDockArea* area = new QDockArea( Qt::Horizontal, QDockArea::Normal, this );
     toolBar = new KToolBar( area );
     tool2Bar = new KToolBar( area );
     tool3Bar = new KToolBar( area );
@@ -65,17 +55,15 @@ MultiLineEditDlg::MultiLineEditDlg( QString text, QWidget *parent, const char *n
     layout->addWidget( area );
     layout->addWidget( editor );
 
-    resize( 500, 300 );
 }
 
-MultiLineEditDlg::~MultiLineEditDlg()
+MultiLineEditor::~MultiLineEditor()
 {
 }
 
 
-void MultiLineEditDlg::setupActions()
+void MultiLineEditor::setupActions()
 {
-    TextFields DataFields ;
     ac = new KActionCollection( this );
 
     KAction* action_export = new KAction( i18n("Export"), "fileexport", 0, this, SLOT( save() ), ac );
@@ -145,9 +133,10 @@ void MultiLineEditDlg::setupActions()
     action_align_right->setExclusiveGroup( "alignment" );
     action_align_justify->setExclusiveGroup( "alignment" );
 
-    KAction* action_spell = KStdAction::spelling( this, SLOT( checkSpelling() ), ac );
+    //KAction* action_spell = KStdAction::spelling( this, SLOT( checkSpelling() ), ac );
 
-    action_export->plug( toolBar );
+    KAction* textDataAct = new KAction( i18n("Insert &Data Field"), "contents", 0, this, SLOT( insertNewField() ), ac, "text_data_act");        action_export->plug( toolBar );
+    
     toolBar->insertSeparator();
     action_undo->plug( toolBar );
     action_redo->plug( toolBar );
@@ -173,10 +162,8 @@ void MultiLineEditDlg::setupActions()
     action_align_right->plug( tool2Bar );
     action_align_justify->plug( tool2Bar );
 
-    action_insert_field = new KComboBox(tool3Bar,"insert_field") ;
-    connect( action_insert_field, SIGNAL( activated(int) ), this, SLOT( insertNewField(int) ) );
-    action_insert_field->insertStringList(DataFields.TextFieldNames) ;
-
+    textDataAct->plug( tool3Bar );
+    
     //
     // Setup enable/disable
     //
@@ -187,34 +174,24 @@ void MultiLineEditDlg::setupActions()
     connect( editor, SIGNAL( cursorPositionChanged( int,int ) ), this, SLOT( updateAligment() ) );
 }
 
-QString MultiLineEditDlg::text()
+QString MultiLineEditor::text()
 {
     return editor->text();
 }
 
-QString MultiLineEditDlg::getText( QString text, bool* ok, QWidget* parent )
+void MultiLineEditor::setText( const QString & t )
 {
-    MultiLineEditDlg* md = new MultiLineEditDlg( text, parent );
-    if( md->exec() == QDialog::Accepted ) {
-        *ok = true;
-        QString t = md->text();
-        delete md;
-        return t;
-    }
-
-    *ok = false;
-    delete md;
-    return "";
+    editor->setText( t );
 }
 
-void MultiLineEditDlg::updateCharFmt()
+void MultiLineEditor::updateCharFmt()
 {
     action_bold->setChecked( editor->bold() );
     action_italic->setChecked( editor->italic() );
     action_underline->setChecked( editor->underline() );
 }
 
-void MultiLineEditDlg::updateAligment()
+void MultiLineEditor::updateAligment()
 {
     int align = editor->alignment();
 
@@ -236,21 +213,21 @@ void MultiLineEditDlg::updateAligment()
     }
 }
 
-void MultiLineEditDlg::updateFont()
+void MultiLineEditor::updateFont()
 {
     if ( editor->pointSize() > 0 )
         action_font_size->setFontSize( editor->pointSize() );
     action_font->setFont( editor->family() );
 }
 
-void MultiLineEditDlg::updateActions()
+void MultiLineEditor::updateActions()
 {
     updateCharFmt();
     updateAligment();
     updateFont();
 }
 
-void MultiLineEditDlg::formatColor()
+void MultiLineEditor::formatColor()
 {
     QColor col;
 
@@ -261,37 +238,38 @@ void MultiLineEditDlg::formatColor()
     editor->setColor( col );
 }
 
-void MultiLineEditDlg::setAlignLeft( bool yes )
+void MultiLineEditor::setAlignLeft( bool yes )
 {
     if ( yes )
         editor->setAlignment( AlignLeft );
 }
 
-void MultiLineEditDlg::setAlignRight( bool yes )
+void MultiLineEditor::setAlignRight( bool yes )
 {
     if ( yes )
         editor->setAlignment( AlignRight );
 }
 
-void MultiLineEditDlg::setAlignCenter( bool yes )
+void MultiLineEditor::setAlignCenter( bool yes )
 {
     if ( yes )
         editor->setAlignment( AlignCenter );
 }
 
-void MultiLineEditDlg::setAlignJustify( bool yes )
+void MultiLineEditor::setAlignJustify( bool yes )
 {
     if ( yes )
         editor->setAlignment( AlignJustify );
 }
 
-void MultiLineEditDlg::insertNewField( int index )
+void MultiLineEditor::insertNewField()
 {
-    TextFields DataFields;
-    editor->insert(  DataFields.TextField(ID_ITEM_FIRST + index)) ;
+    TokenDialog dlg( m_token, this, "dlg" );
+    if( dlg.exec() == QDialog::Accepted )
+        editor->insert( dlg.token() );
 }
 
-void MultiLineEditDlg::checkSpelling()
+void MultiLineEditor::checkSpelling()
 {
 /*
 #if KDE_IS_VERSION( 3, 1, 90 )
@@ -311,13 +289,13 @@ void MultiLineEditDlg::checkSpelling()
 */
 }
 
-void MultiLineEditDlg::spellCheckDone(const QString & buffer)
+void MultiLineEditor::spellCheckDone(const QString & buffer)
 {
     editor->setText( buffer );
     spell->cleanUp();
 }
 
-void MultiLineEditDlg::save()
+void MultiLineEditor::save()
 {
     QString name = KFileDialog::getSaveFileName ( NULL, "*", this );
     if( name.isEmpty() )
@@ -330,3 +308,5 @@ void MultiLineEditDlg::save()
     }
 }
 
+
+#include "multilineeditdlg.moc"
