@@ -22,7 +22,7 @@
 #include <qobject.h>
 
 #include <qvaluelist.h>
-
+#include "barkode.h"
 void init();
 
 typedef union u_settings {
@@ -114,9 +114,7 @@ typedef struct barcodeData {
     } sequence;
 };
 
-/* Serial Indexing/Sequence Modes */
-enum { NUM, ALPHA, ALPHANUM };
-
+#if 0
 enum { NOCUT = 0x00001, MULTILINE = 0x00002, NOTEXT = 0x00004, NOSCALE = 0x00008,
        /**
          * The different Generator Backends
@@ -135,6 +133,7 @@ enum { NOCUT = 0x00001, MULTILINE = 0x00002, NOTEXT = 0x00004, NOSCALE = 0x00008
          * Short cut's
          */
        BARCODE2D =  NOCUT | MULTILINE | NOTEXT };
+#endif
 
 typedef struct barcodeFormat {
     QString name;
