@@ -31,7 +31,9 @@
 #include <kcombobox.h>
 #include <kpushbutton.h>
 
-#define I2S(x) QString("%1").arg(x)
+#ifndef I2S
+    #define I2S(x) QString("%1").arg(x)
+#endif // I2S
 
 NewLabel::NewLabel( QWidget* parent,  const char* name, bool change, WFlags fl )
     : QDialog( parent, name, true, fl )
@@ -162,14 +164,13 @@ void NewLabel::updateText()
     if(!checkEmpty->isChecked())
     {
         Definition d( comboProducer->currentText(), comboType->currentText() );
-        Measurements* m = d.getMeasurements();
         TextLabel4->setText( QString(i18n(
-            "<b>Format:</b><br>\nWidth: ") + I2S(m->width()) +
-            i18n("%1<br>Height: ") + I2S(m->height()) +
-            i18n("%2<br>Horizontal Gap: ") + I2S(m->gapH()) +
-            i18n("%3<br>Vertical Gap: ") + I2S(m->gapV()) +
-            i18n("%4<br>Top Gap: ") + I2S(m->gapTop()) +
-            i18n("%5<br>Left Gap: ") + I2S(m->gapLeft()) + "%6<br>"
+            "<b>Format:</b><br>\nWidth: ") + I2S(d.getMeasurements().width()) +
+            i18n("%1<br>Height: ") + I2S(d.getMeasurements().height()) +
+            i18n("%2<br>Horizontal Gap: ") + I2S(d.getMeasurements().gapH()) +
+            i18n("%3<br>Vertical Gap: ") + I2S(d.getMeasurements().gapV()) +
+            i18n("%4<br>Top Gap: ") + I2S(d.getMeasurements().gapTop()) +
+            i18n("%5<br>Left Gap: ") + I2S(d.getMeasurements().gapLeft()) + "%6<br>"
             ).arg( Measurements::system() )
             .arg( Measurements::system() )
             .arg( Measurements::system() )
@@ -177,8 +178,11 @@ void NewLabel::updateText()
             .arg( Measurements::system() )
             .arg( Measurements::system() ) );
     
-        preview->setRect( QRect( (int)m->gapLeftMM(), (int)m->gapTopMM(), (int)m->widthMM(), (int)m->heightMM() ) );
-        preview->setMeasurements( m );
+        preview->setRect( QRect( (int)d.getMeasurements().gapLeftMM(), 
+                                 (int)d.getMeasurements().gapTopMM(), 
+                                 (int)d.getMeasurements().widthMM(), 
+                                 (int)d.getMeasurements().heightMM() ) );
+        preview->setMeasurements( d.getMeasurements() );
         preview->setPrvEnabled( true );        
         preview->repaint();
         curid = d.getId();
@@ -232,7 +236,7 @@ void NewLabel::add()
         updateType();
         updateText();
     }
-  
+    delete d;
 }
 
 bool NewLabel::empty() const
@@ -240,3 +244,5 @@ bool NewLabel::empty() const
     return checkEmpty->isChecked();
 }
 
+
+#include "newlabel.moc"
