@@ -24,7 +24,7 @@
 #include <kconfig.h>
 #include <kglobal.h>
 #include <klocale.h>
-
+#include <kurl.h>
 
 // Stolen from koffice/lib/kofficecore/koGlobal.cc
 // and modified afterwards
@@ -157,7 +157,7 @@ int PrinterSettings::getQuality() const
     return lpdata->quality == Middle || lpdata->quality == VeryHigh? High : lpdata->quality;
 };
 
-KPrinter* PrinterSettings::setupPrinter( QWidget* parent, bool immediately, const QString & prn )
+KPrinter* PrinterSettings::setupPrinter( const KURL & url, QWidget* parent, bool immediately, const QString & prn )
 {
     KPrinter* printer = new KPrinter( true, (enum QPrinter::PrinterMode)getQuality() );
     if( getData()->quality == Middle )
@@ -173,6 +173,9 @@ KPrinter* PrinterSettings::setupPrinter( QWidget* parent, bool immediately, cons
     if( immediately && !prn.isEmpty() )
         printer->autoConfigure( prn );
 
+    if( !url.isValid() )
+        printer->setDocFileName( url.fileName() );
+        
     return printer;
 }
 
@@ -192,3 +195,5 @@ double PrinterSettings::pageHeight() const
     return pageFormatInfo[lpdata->format].height;
 }
 
+
+#include "printersettings.moc"
