@@ -1,3 +1,4 @@
+
 /***************************************************************************
                          referencecounted.cpp  -  description
                              -------------------
@@ -17,7 +18,6 @@
 
 #include "referencecounted.h"
 
-ReferenceCounted::ReferenceCounted()
-{
-    m_counter = 0;
-}
+
+
+
