@@ -600,6 +600,18 @@ QString TokenProvider::processAddresses( const QString & t )
     if( !m_address || !t.startsWith( "address" ) )
         return ret;
 
+    KABC::Address addr = m_address->address( KABC::Address::Pref );
+    if( addr.isEmpty() )
+    {
+        KABC::Address::List list = m_address->addresses();
+        for( int i=0;i<list.count();i++ )
+            if( !list[i].isEmpty() ) 
+            {
+                addr = list[i];
+                break;
+            }
+    }
+
     if( t == TOK_ADDRESS_NAME )  
     {
         ret = m_address->realName();
@@ -697,47 +709,47 @@ QString TokenProvider::processAddresses( const QString & t )
     }
     else if( t == TOK_ADDRESS_ADDRESS_POB )
     {
-        ret = m_address->address( KABC::Address::Pref ).postOfficeBox();
+        ret = addr.postOfficeBox();
         found = true;
     }
     else if( t == TOK_ADDRESS_ADDRESS_EXTENDED )
     {
-        ret = m_address->address( KABC::Address::Pref ).extended();
+        ret = addr.extended();
         found = true;
     }
     else if( t == TOK_ADDRESS_ADDRESS_STREET )
     {
-        ret = m_address->address( KABC::Address::Pref ).street();
+        ret = addr.street();
         found = true;
     }
     else if( t == TOK_ADDRESS_ADDRESS_LOCALITY )    
     {
-        ret = m_address->address( KABC::Address::Pref ).locality();
+        ret = addr.locality();
         found = true;
     }
     else if( t == TOK_ADDRESS_ADDRESS_REGION )
     {
-        ret = m_address->address( KABC::Address::Pref ).region();
+        ret = addr.region();
         found = true;
     }
     else if( t == TOK_ADDRESS_ADDRESS_POSTALCODE )
     {
-        ret = m_address->address( KABC::Address::Pref ).postalCode();
+        ret = addr.postalCode();
         found = true;
     }
     else if( t == TOK_ADDRESS_ADDRESS_COUNTRY )
     {
-        ret = m_address->address( KABC::Address::Pref ).country();
+        ret = addr.country();
         found = true;
     }
     else if( t == TOK_ADDRESS_ADDRESS_LABEL )
     {
-        ret = m_address->address( KABC::Address::Pref ).label();
+        ret = addr.label();
         found = true;
     }
     else if( t == TOK_ADDRESS )
     {
-        ret = m_address->address( KABC::Address::Pref ).formattedAddress( m_address->realName(), m_address->organization() );
+        ret = addr.formattedAddress( m_address->realName(), m_address->organization() );
         found = true;
     }
     else if( t == TOK_ADDRESS_URL )
